/**
 * This file provides TypeScript bindings to the Rust implementation
 * of parallel Notion API processing.
 */
import { Reporter } from "gatsby";
/**
 * Notion Block type from the Notion API
 */
export type NotionBlock = any;
/**
 * Options for the RustNotionService
 */
export interface RustNotionServiceOptions {
    reporter: Reporter;
    notionApiKey: string;
    parallelLimit?: number;
    enableCaching?: boolean;
}
/**
 * A wrapper class that provides access to the Rust implementation
 * of parallel processing for Notion API, with a fallback to the
 * TypeScript implementation if the Rust module is not available.
 */
export declare class RustNotionService {
    private reporter;
    private notionApiKey;
    private parallelLimit;
    private enableCaching;
    private cache;
    private rustInstance;
    constructor(options: RustNotionServiceOptions);
    /**
     * Get blocks for a single page, with recursive fetching of child blocks
     */
    getPageBlocks(pageId: string): Promise<NotionBlock[]>;
    /**
     * Get blocks for multiple pages in parallel, using Rust implementation if available
     */
    getMultiplePagesBlocks(pageIds: string[]): Promise<{
        [id: string]: NotionBlock[];
    }>;
    /**
     * Set the parallel processing limit
     */
    setParallelLimit(limit: number): void;
}
